@@ -1,5 +1,5 @@
 import json
-from dateutil import parser
+from datetime import datetime
 
 
 def apply(input_path, parameters=None):
@@ -8,5 +8,5 @@ def apply(input_path, parameters=None):
     log_obj = json.load(open(input_path, "rb"))
     for ek in log_obj["ocel:events"]:
         eve = log_obj["ocel:events"][ek]
-        eve["ocel:timestamp"] = parser.parse(eve["ocel:timestamp"])
+        eve["ocel:timestamp"] = datetime.fromisoformat(eve["ocel:timestamp"])
     return log_obj
